**To delete a device certificate**

The following ``delete-certificate`` example deletes the device certificate with the specified ID. ::

    aws iot delete-certificate \
        --certificate-id c0c57bbc8baaf4631a9a0345c957657f5e710473e3ddbee1428d216d54d53ac9

This command produces no output.

For more information, see `DeleteCertificate <https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteCertificate.html>`__ in the *AWS IoT API Reference*.
